<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-safehtml?lang_cible=ar
// ** ne pas modifier le fichier **

return [

	// S
	'safehtml_description' => 'حماية المنتديات من هجمات من نوع الأوامرالعابرة للمواقع ',
	'safehtml_slogan' => 'حماية المنتديات من الأوامرالعابرة للمواقع ',
];
